
/*global jQuery: false, GUI$: false, Cookies: false */
/*jslint vars: true */

/** 
* @preserve Copyright 2020 Pine Grove Software, LLC
* financial-calculators.com
* pine-grove.com
* interface.RETIRE-NESTEGG-WIDGET.gpl.js
*/
(function ($, GUI) {
	'use strict';

	// don't try to initialize the wrong calculator
	if (!document.getElementById('retire-nest-egg-plugin')) {
		return;
	}


	var obj = {}, // interface object to base equations
		// gui controls
		currentAgeInput,
		retireAgeInput,
		pvInput,
		cfInput,
		rateInput;


	/**
	* init() -- init or reset GUI's values
	*/
	function initGUI() {
		currentAgeInput.setValue(currentAgeInput.getUSNumber());
		retireAgeInput.setValue(retireAgeInput.getUSNumber());
		pvInput.setValue(pvInput.getUSNumber());
		cfInput.setValue(cfInput.getUSNumber());
		rateInput.setValue(rateInput.getUSNumber());

		document.getElementById("edFV-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edNumPmts-ne").value = GUI.formatLocalFloat(0, GUI.numConventions, 0);
		document.getElementById("edTotalInvested-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edInterest-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edFVDate-ne").value = GUI.dateConventions.date_mask;

	} // initGUI



	/**
	* clearGUI() -- reset GUI's values
	*/
	function clearGUI() {

		currentAgeInput.setValue(0);
		retireAgeInput.setValue(0);
		pvInput.setValue(0.0);
		cfInput.setValue(0.0);
		rateInput.setValue(0.0);


		document.getElementById("edFV-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edNumPmts-ne").value = GUI.formatLocalFloat(0, GUI.numConventions, 0);
		document.getElementById("edTotalInvested-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edInterest-ne").value = GUI.formatLocalFloat(0.0, GUI.moneyConventions, 2);
		document.getElementById("edFVDate-ne").value = GUI.dateConventions.date_mask;

	} // clearGUI



	/**
	* getInputs() -- get user inputs and initialize obj equation interface object
	*/
	function getInputs() {
		var yrs;
		// all rates are passed as decimal equivalents
		obj = {};
		if (currentAgeInput.getUSNumber() <= 0) {
			alert('"Current Age" must be greater than 0.');
			return null;
		}
		if (retireAgeInput.getUSNumber() > currentAgeInput.getUSNumber()) {
			yrs = (retireAgeInput.getUSNumber() - currentAgeInput.getUSNumber()) + 1;
		} else {
			alert('"Retirement Age" must be greater than "Current Age"');
			return null;
		}
		obj.n = yrs * 12;
		obj.pv = pvInput.getUSNumber();
		obj.cf = cfInput.getUSNumber();
		obj.nominalRate = rateInput.getUSNumber() / 100;


		obj.oDate = GUI.dateMath.getFirstNextMonth(new Date());
		obj.oDate.setHours(0, 0, 0, 0);
		obj.fDate = GUI.dateMath.getFirstNextMonth(new Date(obj.oDate));
		obj.lDate = new Date();

		obj.pmtFreq = 6;
		obj.cmpFreq = 6;
		obj.pmtMthd = 0;
		return 1;
	} // getInputs()



	/** 
	* calc() -- initialize CashInputs data structures for equation classes
	*/
	function calc() {
		var invested, interest, bal;

		getInputs();
		// ca = currentAgeInput.getUSNumber();
		// if (ca <= 0) {
		// alert('Current age must be greater than 0.');
		// return null;
		// }
		if (obj.n === 0 || (obj.pv === 0 && obj.cf === 0) || obj.nominalRate === 0) {
			alert('There are unknown values.\nPlease make sure all values are entered.\n\n"Current Retirement Savings" can be 0.');
			return null;
		}

		// obj.fv = 0;
		// obj.fv = GUI.FV.calc(obj);

		obj.lDate.setTime(GUI.dateMath.addPeriods(obj.oDate, obj.n, obj.pmtFreq));
		GUI.RETIRE_NESTEGG_SCHEDULE.calc(obj);
		obj.fv = GUI.summary.unadjustedBalance;
		invested = GUI.summary.totalPmts[1];
		interest = GUI.summary.totalInterest[1];
		bal = GUI.summary.unadjustedBalance;

		document.getElementById("edFV-ne").value = GUI.formatLocalFloat(obj.fv, GUI.moneyConventions, 2);
		document.getElementById("edNumPmts-ne").value = GUI.formatLocalFloat(obj.n, GUI.numConventions, 0);
		document.getElementById("edTotalInvested-ne").value = GUI.formatLocalFloat(GUI.roundMoney(invested, 2), GUI.moneyConventions, 2);
		document.getElementById("edInterest-ne").value = GUI.formatLocalFloat(GUI.roundMoney(interest, 2), GUI.moneyConventions, 2);
		document.getElementById('edFVDate-ne').value = GUI.dateMath.dateToDateStr(obj.lDate, GUI.dateConventions);
		return 1;
	} // function calc()




	$(document).ready(function () {

		// If user has a ccy_format cookie, use its value first
		// otherwise if website set default currency use it
		// otherwise use currency determined by user's locale - previously initialized
		var currency = parseInt(document.getElementById('currency-ne').value, 10);
		if (Cookies.get('ccy_format')) {
			GUI.updateNumConventions(parseInt(Cookies.get('ccy_format'), 10));
			// GUI.moneyConventions = new GUI.LocalConventions(parseInt(Cookies.get('ccy_format'), 10));
			// // clones moneyConventions and sets ccy_r = '%'
			// GUI.rateConventions = GUI.moneyConventions.rateConvention(); // clones currency conventions with'%' symbol
			// GUI.numConventions = GUI.moneyConventions.numConvention(); // clones currency conventions without currency
		} else if (currency !== undefined && currency !== null && typeof currency === 'number' && currency !== 999) {
			GUI.updateNumConventions(currency);
		}

		// If user has a date_format cookie, use its value first
		// otherwise if website set default date_mask use it
		// otherwise use date_mask determined by user's locale - previously initialized
		var date_mask = parseInt(document.getElementById('date_mask-ne').value, 10);
		if (Cookies.get('date_format')) {
			GUI.dateConventions = new GUI.LocalDateConventions(parseInt(Cookies.get('date_format'), 10));
		} else if (date_mask !== undefined && date_mask !== null && typeof date_mask === 'number' && date_mask !== 999) {
			GUI.updateDateConventions(date_mask);
		}

		//
		// initialize GUI controls & dialog / modal controls here
		// attach
		//

		// only required on the financial-calculators.com site
		// here for each comment reply link of WordPress
		// $('.comment-reply-link').addClass('btn btn-primary');

		// here for the submit button of the comment reply form
		// $('#submit').addClass('btn btn-primary');

		// Style contact form submit button
		// $('.wpcf7-submit').addClass('btn btn-primary');

		// Add thumbnail styling
		// $('.wp-caption').addClass('thumbnail');

		// Now we'll add some classes for the WordPress default widgets - let's go
		// Add Bootstrap style for drop-downs
		// $('.postform').addClass('form-control');
		// end: only required on the financial-calculators.com site


		// main window
		currentAgeInput = new GUI.NE('edCurrentAge-ne', GUI.numConventions, 0);
		retireAgeInput = new GUI.NE('edRetirementAge-ne', GUI.numConventions, 0);
		pvInput = new GUI.NE('edPV-ne', GUI.moneyConventions, 2);
		cfInput = new GUI.NE('edCF-ne', GUI.moneyConventions, 2);
		rateInput = new GUI.NE('edRate-ne', GUI.rateConventions, 4);

		initGUI();


		$('#btnCalc-ne').click(function () {
			// getInputs();
			calc();
		});


		$('#btnClear-ne').click(function () {
			clearGUI();
		});


		$('#btnPrint-ne').click(function () {
			// getInputs();
			calc();
			GUI.print_calc();
		});


		$('#btnSchedule-ne').click(function () {
			// getInputs();
			if (calc() !== null) {
				GUI.showSavingsSchedule(GUI.RETIRE_NESTEGG_SCHEDULE.calc(obj));
			}
		});


		$('#btnCharts-ne').click(function () {
			// getInputs();
			if (calc() !== null) {
				GUI.showSavingsCharts(GUI.RETIRE_NESTEGG_SCHEDULE.calc(obj));
			}
		});


		$('#btnHelp-ne').click(function () {
			GUI.show_help('#hText-retire-nest-egg');
		});


		$('#btnCcyDate, #btnCcyDate2, #CCY-ne').click(function () {
			GUI$.init_CURRENCYDATE_Dlg();
		});

	}); // $(document).ready

}(jQuery, GUI$));
